# Eqxvision

Eqxvision is a package of popular computer vision model architectures built using [Equinox](https://docs.kidger.site/equinox/).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install eqxvision.

```bash
pip install eqxvision
```

*requires:* `python>=3.7`

## Usage

```python title="forward.py"
import jax
import jax.random as jr
import equinox as eqx
from eqxvision.models import alexnet

@eqx.filter_jit
def forward(net, images, key):
    keys = jax.random.split(key, images.shape[0])
    output = jax.vmap(net, axis_name=('batch'))(images, key=keys)
    ...
    
net = alexnet(num_classes=1000)

images = jr.uniform(jr.PRNGKey(0), shape=(1,3,224,224))
output = forward(net, images, jr.PRNGKey(0))
```

```python title="set_inference.py"
import equinox as eqx
from eqxvision.models import alexnet

net = alexnet(num_classes=1000)
net = eqx.tree_inference(net, True)
```

## Tips
- Checkout the documentation for a sample usage for each model;
- Better to use `@equinox.jit_filter` instead of `@jax.jit`;
- Advisable to use `jax.vmap` with `axis_name='batch'` for all models;
- Don't forget to switch to `inference` mode for evaluations.


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Acknowledgements
- [Equinox](https://github.com/patrick-kidger/equinox)
- [Patrick Kidger](https://github.com/patrick-kidger)
- [Torchvision](https://pytorch.org/vision/stable/index.html)

## License
[MIT](https://choosealicense.com/licenses/mit/)